@@ -15,6 +15,7 @@ namespace stan {
     struct row_vector_expr;
     struct variable;
     struct fun;
+    struct integrate_1d;
     struct integrate_ode;
     struct integrate_ode_control;
     struct algebra_solver;
@@ -110,6 +111,15 @@ namespace stan {
        */
       bool operator()(const fun& e) const;
 
+      /**
+       * Return true if the variable occurs in the specified
+       * expression.
+       *
+       * @param[in] e expression
+       * @return true if the variable occurs in the arguments
+       */
+      bool operator()(const integrate_1d& e) const;
+
       /**
        * Return true if the variable occurs in the specified
        * expression.
