@@ -1,10 +1,10 @@
 #ifndef STAN_LANG_AST_NODE_MATRIX_EXPR_HPP
 #define STAN_LANG_AST_NODE_MATRIX_EXPR_HPP
 
-#include <stan/lang/ast/expr_type.hpp>
 #include <stan/lang/ast/scope.hpp>
 #include <stan/lang/ast/node/expression.hpp>
 #include <vector>
+#include <cstddef>
 
 namespace stan {
   namespace lang {
