@@ -8,14 +8,14 @@ namespace stan {
   namespace lang {
 
     struct nil;
-    struct assignment;
     struct assgn;
-    struct compound_assignment;
     struct sample;
     struct increment_log_prob_statement;
     struct expression;
     struct statements;
     struct for_statement;
+    struct for_array_statement;
+    struct for_matrix_statement;
     struct conditional_statement;
     struct while_statement;
     struct break_continue_statement;
@@ -32,14 +32,14 @@ namespace stan {
        * The variant type of statements.
        */
       typedef boost::variant<boost::recursive_wrapper<nil>,
-                     boost::recursive_wrapper<assignment>,
                      boost::recursive_wrapper<assgn>,
-                     boost::recursive_wrapper<compound_assignment>,
                      boost::recursive_wrapper<sample>,
                      boost::recursive_wrapper<increment_log_prob_statement>,
                      boost::recursive_wrapper<expression>,
                      boost::recursive_wrapper<statements>,
                      boost::recursive_wrapper<for_statement>,
+                     boost::recursive_wrapper<for_array_statement>,
+                     boost::recursive_wrapper<for_matrix_statement>,
                      boost::recursive_wrapper<conditional_statement>,
                      boost::recursive_wrapper<while_statement>,
                      boost::recursive_wrapper<break_continue_statement>,
@@ -70,14 +70,6 @@ namespace stan {
        */
       statement(const nil& st);  // NOLINT(runtime/explicit)
 
-      /**
-       * Construct a statement variant type wrapper from the specified
-       * basic statement.
-       *
-       * @param st basic statement
-       */
-      statement(const assignment& st);  // NOLINT(runtime/explicit)
-
       /**
        * Construct a statement variant type wrapper from the specified
        * basic statement.
@@ -86,14 +78,6 @@ namespace stan {
        */
       statement(const assgn& st);  // NOLINT(runtime/explicit)
 
-      /**
-       * Construct a statement variant type wrapper from the specified
-       * basic statement.
-       *
-       * @param st basic statement
-       */
-      statement(const compound_assignment& st);  // NOLINT(runtime/explicit)
-
       /**
        * Construct a statement variant type wrapper from the specified
        * basic statement.
@@ -134,6 +118,22 @@ namespace stan {
        */
       statement(const for_statement& st);  // NOLINT(runtime/explicit)
 
+      /**
+       * Construct a statement variant type wrapper from the specified
+       * basic statement.
+       *
+       * @param st basic statement
+       */
+      statement(const for_array_statement& st);  // NOLINT(runtime/explicit)
+
+      /**
+       * Construct a statement variant type wrapper from the specified
+       * basic statement.
+       *
+       * @param st basic statement
+       */
+      statement(const for_matrix_statement& st);  // NOLINT(runtime/explicit)
+
       /**
        * Construct a statement variant type wrapper from the specified
        * basic statement.
