@@ -1,7 +1,7 @@
 #ifndef STAN_LANG_AST_NODE_VARIABLE_HPP
 #define STAN_LANG_AST_NODE_VARIABLE_HPP
 
-#include <stan/lang/ast/expr_type.hpp>
+#include <stan/lang/ast/type/bare_expr_type.hpp>
 #include <cstddef>
 #include <string>
 
@@ -20,7 +20,7 @@ namespace stan {
       /**
        * Type of variable.
        */
-      expr_type type_;
+      bare_expr_type type_;
 
       /**
        * Construct a default variable.
@@ -35,13 +35,11 @@ namespace stan {
       variable(const std::string& name);  // NOLINT(runtime/explicit)
 
       /**
-       * Set the type of the variable to the expression type
-       * with the specified base type and number of dimensions.
+       * Set the variable type.
        *
-       * @param base_type base type for variable
-       * @param num_dims number of array dims for variable
+       * @param bare_type bare expression type
        */
-      void set_type(const base_expr_type& base_type, std::size_t num_dims);
+      void set_type(const bare_expr_type& bare_type);
     };
 
   }
