@@ -1,8 +1,7 @@
 #ifndef STAN_LANG_AST_SIGS_FUNCTION_SIGNATURE_T_HPP
 #define STAN_LANG_AST_SIGS_FUNCTION_SIGNATURE_T_HPP
 
-#include <stan/lang/ast/expr_type.hpp>
-#include <stan/lang/ast/sigs/function_arg_type.hpp>
+#include <stan/lang/ast/type/bare_expr_type.hpp>
 #include <utility>
 #include <vector>
 
@@ -13,7 +12,7 @@ namespace stan {
      * The type of a function signature, mapping a vector of
      * argument expression types to a result expression type.
      */
-    typedef std::pair<expr_type, std::vector<function_arg_type> >
+    typedef std::pair<bare_expr_type, std::vector<bare_expr_type> >
     function_signature_t;
 
   }
