@@ -2,6 +2,7 @@
 #define STAN_MATH_PRIM_MAT_ERR_IS_LOWER_TRIANGULAR_HPP
 
 #include <Eigen/Dense>
+#include <functional>
 
 namespace stan {
 namespace math {
@@ -22,7 +23,7 @@ inline double notNan(double x) { return std::isnan(x) ? 1.0 : x; }
 template <typename T_y>
 inline bool is_lower_triangular(
     const Eigen::Matrix<T_y, Eigen::Dynamic, Eigen::Dynamic>& y) {
-  return y.unaryExpr(std::ptr_fun(internal::notNan))
+  return y.unaryExpr(std::function<double(double)>(internal::notNan))
       .transpose()
       .isUpperTriangular();
 }
